Cartesian class final
- Implemented types
- Available extensions
Constructors
Properties
- hashCode → int
-
Get a hashCode for the complex number.
no setteroverride
- imaginary → double
-
The imaginary part.
final
- isFinite → bool
-
True if the real and imaginary parts are finite; otherwise, false.
no setteroverride
- isInfinite → bool
-
True if the real and imaginary parts are positive infinity or negative
infinity; otherwise, false.
no setteroverride
- isNaN → bool
-
True if the real and imaginary parts are the double Not-a-Number value;
otherwise, false.
no setteroverride
- real → double
-
The real part.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
abs(
) → double -
Return the absolute value of this complex number.
Returns
NaNif either real or imaginary part isNaNanddouble.INFINITYif neither part isNaN, but at least one part is infinite.override -
acos(
) → Complex -
Available on T, provided by the ComplexTrigonometricX extension
Arccosine -
argument(
) → double -
Compute the argument of this complex number.
override
-
asin(
) → Complex -
Available on T, provided by the ComplexTrigonometricX extension
Arcsine -
atan(
) → Complex -
Available on T, provided by the ComplexTrigonometricX extension
Arctangent -
conjugate(
) → Cartesian -
Return the conjugate of this complex number.
The conjugate of
a + biisa - bi.override -
cos(
) → Complex -
Available on T, provided by the ComplexTrigonometricX extension
Cosine -
cosh(
) → Complex -
Available on T, provided by the ComplexHyperbolicX extension
Hyperbolic cosine -
exp(
) → Cartesian -
Compute the exponential function
of this complex number.
override
-
log(
) → Cartesian -
Compute the natural logarithm
of this complex number.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
nthRoot(
int n) → List< Complex> -
Available on T, provided by the ComplexRootsX extension
ComplexRootsX -
pow(
num x) → Cartesian -
Returns of value of this complex number raised to the power of
x.override -
power<
T extends Complex> (T z) → Cartesian -
Returns of value of this complex number raised to the power of
x.override -
reciprocal(
) → Cartesian -
Returns the multiplicative inverse of
thiselement.override -
sin(
) → Complex -
Available on T, provided by the ComplexTrigonometricX extension
Sine -
sinh(
) → Complex -
Available on T, provided by the ComplexHyperbolicX extension
Hyperbolic sine -
sqrt(
) → Cartesian -
Compute the square root
of this complex number.
override
-
sqrt1z(
) → Cartesian -
Compute the square root
of
1 - this^2for this complex number.override -
tan(
) → Complex -
Available on T, provided by the ComplexTrigonometricX extension
Tangent -
tanh(
) → Complex -
Available on T, provided by the ComplexHyperbolicX extension
Hyperbolic tangent -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator *(
Object factor) → Cartesian -
Returns a
Complexwhose value isthis * factor. Implements preliminary checks forNaNand infinity followed by the definitional formula:override -
operator +(
Object addend) → Cartesian -
Returns a
Complexwhose value is(this + addend). Uses the definitional formulaoverride -
operator -(
Object subtrahend) → Cartesian -
Returns a
Complexwhose value isthis - subtrahend. Uses the definitional formulaoverride -
operator /(
Object divisor) → Cartesian -
Returns a
Complexwhose value is(this / divisor). Implements the definitional formulaoverride -
operator ==(
Object other) → bool -
The equality operator.
override
-
operator unary-(
) → Cartesian -
Returns a
Complexwhose value isthis - subtrahend. Uses the definitional formulaoverride